from distutils.core import setup

setup(name="nester10086", version='1.5.0', py_modules=['nester'], author='wangxin', author_email='springnap@163.com', url='http://goldingking@github.com', description='add indent switcher')
